==> web-10.0.0.tgz: package/lib/myTable/treeTable/TabView.js <==
import * as React from "react";
import ParTree from "./ParTree";
import TrItem from "./TrItem";
import { ScrollBox } from "../../scroll/index";
import { closertPar } from "../../util/domUtil";
class TabView extends React.PureComponent {
    constructor() {
        super(...arguments);
        this.colHeadRef = React.createRef();
        this.tabBodyRef = React.createRef();
        this.state = {};
        this.overBoxTimer = 0;
        this.scrollBoxMethod = undefined;
        this.bindScrollboxFn = (method) => {
            this.scrollBoxMethod = method;
        };
        this.originScrollFn = (e) => {
            if (!e.currentTarget.classList.contains("action-body")) {
                return;
            }
            const { changeScrollTop, viewIndex } = this.props;
            const dom = e.currentTarget;
            const left = dom.scrollLeft;
            const colHead = this.colHeadRef.current;
            colHead.scrollLeft = left;
            changeScrollTop(dom.scrollTop, viewIndex);
        };
        this.wheelFn = (e) => {
            e.preventDefault();
            const { changeScrollTop, viewIndex } = this.props;
            const top = this.tabBodyRef.current.scrollTop;
            const step = e.deltaY > 0 ? 10 : -10;
            const distance = top + step;
            this.tabBodyRef.current.scrollTop = distance;
            const realDistance = this.tabBodyRef.current.scrollTop;
            this.tabBodyRef.current.dataset.top = `${realDistance}`;
            changeScrollTop(realDistance, viewIndex);
        };
        this.makeSign = (e) => {
            e.preventDefault();
            const type = e.type;
            const dom = e.currentTarget;
            if (type === "mouseenter") {
                dom.classList.add("action-body");
            }
            else if (type === "mouseleave") {
                dom.classList.remove("action-body");
            }
        };
        this.scrollInitOnslideAfter = () => {
            if (!this.scrollBoxMethod) {
                return;
            }
            this.scrollBoxMethod.initScroll();
            const firstTabBodyRef = closertPar(this.tabBodyRef.current, "tab-viewBody").previousElementSibling.lastElementChild.firstElementChild;
            const top = firstTabBodyRef.scrollTop;
            const preTop = firstTabBodyRef.dataset.top;
            if (top.toString() !== preTop) {
                this.props.changeScrollTop(top, 0);
                firstTabBodyRef.dataset.top = `${top}`;
            }
        };
        this.scrollCallback = (value, isVertical) => {
            if (isVertical) {
                const { changeScrollTop, viewIndex } = this.props;
                changeScrollTop(-value, viewIndex);
            }
            else {
                const colHead = this.colHeadRef.current;
                colHead.scrollLeft = -value;
            }
        };
    }
    gethead() {
        const { config: { child: cols }, } = this.props;
        const tds = cols.map((val) => {
            const { text, width, field } = val;
            return (React.createElement("th", { style: { width: width }, className: "td-border", key: field }, text));
        });
        return (React.createElement("div", { className: "tab-head" },
            React.createElement("table", null,
                React.createElement("thead", null,
                    React.createElement("tr", null, tds)))));
    }
    createColgroup() {
        const { config: { child: cols }, } = this.props;
        const arr = cols.map((val) => {
            const { width, field } = val;
            const style = width ? { width } : undefined;
            return React.createElement("col", { style: style, key: field });
        });
        return React.createElement("colgroup", null, arr);
    }
    componentDidMount() {
        const { setTabBodyDom, viewIndex, config } = this.props;
        if (!config.forzen) {
            this.overBox();
        }
        const { current } = this.tabBodyRef;
        setTabBodyDom(current, viewIndex, this.scrollBoxMethod);
        if (config.forzen) {
            current.addEventListener("wheel", this.wheelFn);
        }
    }
    componentDidUpdate(preProps) {
        if (preProps.data !== this.props.data && this.props.originScroll) {
            clearTimeout(this.overBoxTimer);
            const tbodyDom = this.tabBodyRef.current;
            const child = this.colHeadRef.current
                .firstElementChild;
            this.overBoxTimer = window.setTimeout(() => {
                if (tbodyDom.scrollHeight > tbodyDom.clientHeight) {
                    child.style.paddingRight = "18px";
                }
                else {
                    child.style.paddingRight = "";
                }
            }, 300);
        }
        if (this.scrollBoxMethod && preProps.isreLoad !== this.props.isreLoad) {
            this.scrollBoxMethod.initScroll();
        }
    }
    componentWillUnmount() {
        const { config } = this.props;
        if (config.forzen) {
            this.tabBodyRef.current.removeEventListener("wheel", this.wheelFn);
        }
        clearTimeout(this.overBoxTimer);
    }
    overBox() {
        const tbodyDom = this.tabBodyRef.current;
        if (tbodyDom.scrollWidth > tbodyDom.clientWidth || tbodyDom.scrollHeight > tbodyDom.clientHeight) {
            const child = this.colHeadRef.current
                .firstElementChild;
            child.style.paddingRight = "18px";
        }
    }
    getBody() {
        const { data, fixObj, fixObj: { idField, childField }, config, viewIndex, originScroll, changeState, } = this.props;
        const { child: cols } = config;
        let order = { order: 0 };
        const trs = data.map((val, index) => {
            const arr = val.get(childField);
            const id = val.get(idField);
            const isMainView = viewIndex === 0;
            if (arr && arr.size) {
                return (React.createElement(ParTree, { key: id, order: order, scrollInit: this.scrollInitOnslideAfter, changeState: changeState, lev: 0, index: `${index}`, node: val, cols: cols, isMainView: isMainView, fixObj: fixObj }));
            }
            else {
                return (React.createElement(TrItem, { key: id, order: order, node: val, index: `${index}`, changeState: changeState, cols: cols, isMainView: isMainView, lev: 0, fixObj: fixObj }));
            }
        });
        const colgroup = this.createColgroup();
        const fn = !config.forzen && originScroll ? this.originScrollFn : undefined;
        const makeSignFn = !config.forzen && originScroll ? this.makeSign : undefined;
        return (React.createElement("div", { className: "tab-body-main", onScroll: fn, onMouseEnter: makeSignFn, onMouseLeave: makeSignFn, ref: this.tabBodyRef },
            React.createElement("table", null,
                colgroup,
                React.createElement("tbody", null, trs))));
    }
    render() {
        const { config: { width, forzen }, config, originScroll } = this.props;
        const styleObj = width ? forzen ? { width } : { width, flex: "none" } : undefined;
        const className = config.forzen ? "tab-view-fix" : "tab-view-scroll";
        const body = forzen || originScroll ? React.createElement("div", { className: "tab-body-wrap" }, this.getBody()) : (React.createElement(ScrollBox, { scrollWidthAuto: true, scrollCallback: this.scrollCallback, bindIntiScroll: this.bindScrollboxFn }, this.getBody()));
        return (React.createElement("div", { className: `${className} tab-viewBody`, style: styleObj },
            React.createElement("div", { className: "tab-head-wrap", ref: this.colHeadRef }, this.gethead()),
            body));
    }
}
export default TabView;

==> web-10.1.0.tgz: package/lib/myTable/treeTable/TabView.js <==
import * as React from "react";
import ParTree from "./ParTree";
import TrItem from "./TrItem";
import { ScrollBox } from "../../scroll/index";
import { closertPar } from "../../util/domUtil";
class TabView extends React.PureComponent {
    constructor() {
        super(...arguments);
        this.colHeadRef = React.createRef();
        this.tabBodyRef = React.createRef();
        this.state = {};
        this.overBoxTimer = 0;
        this.scrollBoxMethod = undefined;
        this.bindScrollboxFn = (method) => {
            this.scrollBoxMethod = method;
        };
        this.originScrollFn = (e) => {
            if (!e.currentTarget.classList.contains("action-body")) {
                return;
            }
            const { changeScrollTop, viewIndex } = this.props;
            const dom = e.currentTarget;
            const left = dom.scrollLeft;
            const colHead = this.colHeadRef.current;
            colHead.scrollLeft = left;
            changeScrollTop(dom.scrollTop, viewIndex);
        };
        this.wheelFn = (e) => {
            e.preventDefault();
            const { changeScrollTop, viewIndex } = this.props;
            const top = this.tabBodyRef.current.scrollTop;
            const step = e.deltaY > 0 ? 20 : -20;
            const distance = top + step;
            this.tabBodyRef.current.scrollTop = distance;
            const realDistance = this.tabBodyRef.current.scrollTop;
            this.tabBodyRef.current.dataset.top = `${realDistance}`;
            changeScrollTop(realDistance, viewIndex);
        };
        this.makeSign = (e) => {
            e.preventDefault();
            const type = e.type;
            const dom = e.currentTarget;
            if (type === "mouseenter") {
                dom.classList.add("action-body");
            }
            else if (type === "mouseleave") {
                dom.classList.remove("action-body");
            }
        };
        this.scrollInitOnslideAfter = () => {
            if (!this.scrollBoxMethod) {
                return;
            }
            this.scrollBoxMethod.initScroll();
            if (this.props.totalView === 1) {
                return;
            }
            const firstTabBodyRef = closertPar(this.tabBodyRef.current, "tab-viewBody").previousElementSibling.lastElementChild.firstElementChild;
            const top = firstTabBodyRef.scrollTop;
            const preTop = firstTabBodyRef.dataset.top;
            if (top.toString() !== preTop) {
                this.props.changeScrollTop(top, 0);
                firstTabBodyRef.dataset.top = `${top}`;
            }
        };
        this.scrollCallback = (value, isVertical) => {
            if (isVertical) {
                const { changeScrollTop, viewIndex } = this.props;
                changeScrollTop(-value, viewIndex);
            }
            else {
                const colHead = this.colHeadRef.current;
                colHead.scrollLeft = -value;
            }
        };
    }
    gethead() {
        const { config: { child: cols }, } = this.props;
        const tds = cols.map((val) => {
            const { text, width, field, align = "" } = val;
            return (React.createElement("th", { style: { width: width }, "data-field": field, className: `td-border ${align}`, key: field }, text));
        });
        return (React.createElement("div", { className: "tab-head" },
            React.createElement("table", null,
                React.createElement("thead", null,
                    React.createElement("tr", null, tds)))));
    }
    createColgroup() {
        const { config: { child: cols }, } = this.props;
        const arr = cols.map((val) => {
            const { width, field } = val;
            const style = width ? { width } : undefined;
            return React.createElement("col", { style: style, key: field });
        });
        return React.createElement("colgroup", null, arr);
    }
    componentDidMount() {
        const { setTabBodyDom, viewIndex, config } = this.props;
        if (!config.forzen) {
            this.overBox();
        }
        const { current } = this.tabBodyRef;
        setTabBodyDom(current, viewIndex, this.scrollBoxMethod);
        if (config.forzen) {
            current.addEventListener("wheel", this.wheelFn);
        }
    }
    componentDidUpdate(preProps) {
        if (preProps.data !== this.props.data && this.props.originScroll) {
            clearTimeout(this.overBoxTimer);
            const tbodyDom = this.tabBodyRef.current;
            const child = this.colHeadRef.current
                .firstElementChild;
            this.overBoxTimer = window.setTimeout(() => {
                if (tbodyDom.scrollHeight > tbodyDom.clientHeight) {
                    child.style.paddingRight = "18px";
                }
                else {
                    child.style.paddingRight = "";
                }
            }, 300);
        }
        if (this.scrollBoxMethod && preProps.isreLoad !== this.props.isreLoad) {
            this.scrollBoxMethod.initScroll();
        }
    }
    componentWillUnmount() {
        const { config } = this.props;
        if (config.forzen) {
            this.tabBodyRef.current.removeEventListener("wheel", this.wheelFn);
        }
        clearTimeout(this.overBoxTimer);
    }
    overBox() {
        const tbodyDom = this.tabBodyRef.current;
        if (tbodyDom.scrollWidth > tbodyDom.clientWidth || tbodyDom.scrollHeight > tbodyDom.clientHeight) {
            const child = this.colHeadRef.current
                .firstElementChild;
            child.style.paddingRight = "18px";
        }
    }
    getBody() {
        const { data, fixObj, fixObj: { idField, childField }, config, viewIndex, originScroll, changeState, } = this.props;
        const { child: cols } = config;
        const trs = data.map((val, index) => {
            const arr = val.get(childField);
            const id = val.get(idField);
            const isMainView = viewIndex === 0;
            if (arr && arr.size) {
                return (React.createElement(ParTree, { key: id, scrollInit: this.scrollInitOnslideAfter, changeState: changeState, lev: 0, index: `${index}`, node: val, cols: cols, isMainView: isMainView, fixObj: fixObj }));
            }
            else {
                return (React.createElement(TrItem, { key: id, node: val, index: `${index}`, changeState: changeState, cols: cols, isMainView: isMainView, lev: 0, fixObj: fixObj }));
            }
        });
        const colgroup = this.createColgroup();
        const fn = !config.forzen && originScroll ? this.originScrollFn : undefined;
        const makeSignFn = !config.forzen && originScroll ? this.makeSign : undefined;
        return (React.createElement("div", { className: "tab-body-main", onScroll: fn, onMouseEnter: makeSignFn, onMouseLeave: makeSignFn, ref: this.tabBodyRef },
            React.createElement("table", null,
                colgroup,
                React.createElement("tbody", null, trs))));
    }
    render() {
        const { config: { width, forzen }, config, originScroll } = this.props;
        const styleObj = width ? forzen ? { width } : { width, flex: "none" } : undefined;
        const className = config.forzen ? "tab-view-fix" : "tab-view-scroll";
        const body = forzen || originScroll ? React.createElement("div", { className: "tab-body-wrap" }, this.getBody()) : (React.createElement(ScrollBox, { scrollWidthAuto: true, scrollCallback: this.scrollCallback, bindIntiScroll: this.bindScrollboxFn }, this.getBody()));
        return (React.createElement("div", { className: `${className} tab-viewBody`, style: styleObj },
            React.createElement("div", { className: "tab-head-wrap", ref: this.colHeadRef }, this.gethead()),
            body));
    }
}
export default TabView;
